@@ -92,7 +92,8 @@ async function handler(event) {
     const putObject = await s3.putObject({
       Bucket: getEnv("BUCKET_NAME"),
       Key: key,
-      WebsiteRedirectLocation: body.url
+      ContentType: "text/html",
+      Body: `<html><head><meta http-equiv="Refresh" content="0;url=${body.url}"/></head></html>`
     }).promise();
     console.log("Put object: %j", putObject);
     return __spreadProps(__spreadValues({}, response), {
